import { ServiceClientOptions } from "@azure/ms-rest-js";
import * as msRest from "@azure/ms-rest-js";
/**
 * An interface representing TokenResponse.
 */
export interface TokenResponse {
    /**
     * @member {string} [channelId]
     */
    channelId?: string;
    /**
     * @member {string} [connectionName]
     */
    connectionName?: string;
    token?: string;
    expiration?: string;
}
/**
 * An interface representing InnerHttpError.
 */
export interface InnerHttpError {
    statusCode?: number;
    body?: any;
}
/**
 * An interface representing ErrorModel.
 */
export interface ErrorModel {
    code?: string;
    message?: string;
    innerHttpError?: InnerHttpError;
}
/**
 * An interface representing ErrorResponse.
 */
export interface ErrorResponse {
    error?: ErrorModel;
}
/**
 * An interface representing AadResourceUrls.
 */
export interface AadResourceUrls {
    resourceUrls?: string[];
}
/**
 * The status of a particular token
 */
export interface TokenStatus {
    /**
     * @member {string} [channelId] The channelId of the token status pertains to
     */
    channelId?: string;
    /**
     * @member {string} [connectionName] The name of the connection the token
     * status pertains to
     */
    connectionName?: string;
    /**
     * True if a token is stored for this ConnectionName
     */
    hasToken?: boolean;
    /**
     * The display name of the service provider for which this Token belongs to
     */
    serviceProviderDisplayName?: string;
}
/**
 * An interface representing TokenApiClientOptions.
 */
export interface TokenApiClientOptions extends ServiceClientOptions {
    baseUri?: string;
}
/**
 * Optional Parameters.
 */
export interface BotSignInGetSignInUrlOptionalParams extends msRest.RequestOptionsBase {
    codeChallenge?: string;
    emulatorUrl?: string;
    finalRedirect?: string;
}
/**
 * Optional Parameters.
 */
export interface UserTokenGetTokenOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {string} [channelId]
     */
    channelId?: string;
    /**
     * @member {string} [code]
     */
    code?: string;
}
/**
 * @interface
 * An interface representing UserTokenGetAadTokensOptionalParams.
 * Optional Parameters.
 *
 * @extends RequestOptionsBase
 */
export interface UserTokenGetAadTokensOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {string} [channelId]
     */
    channelId?: string;
}
/**
 * @interface
 * An interface representing UserTokenSignOutOptionalParams.
 * Optional Parameters.
 */
export interface UserTokenSignOutOptionalParams extends msRest.RequestOptionsBase {
    connectionName?: string;
    /**
     * @member {string} [channelId]
     */
    channelId?: string;
}
/**
 * Optional Parameters.
 */
export interface UserTokenGetTokenStatusOptionalParams extends msRest.RequestOptionsBase {
    /**
     * @member {string} [channelId]
     */
    channelId?: string;
    /**
     * @member {string} [include]
     */
    include?: string;
}
/**
 * Contains response data for the getSignInUrl operation.
 */
export declare type BotSignInGetSignInUrlResponse = {
    /**
     * The parsed response body.
     */
    body: string;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: string;
    };
};
/**
 * Contains response data for the getToken operation.
 */
export declare type UserTokenGetTokenResponse = TokenResponse & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: TokenResponse;
    };
};
/**
 * Contains response data for the getAadTokens operation.
 */
export declare type UserTokenGetAadTokensResponse = {
    /**
     * The response body properties.
     */
    [propertyName: string]: TokenResponse;
} & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: {
            [propertyName: string]: TokenResponse;
        };
    };
};
/**
 * Contains response data for the signOut operation.
 */
export declare type UserTokenSignOutResponse = {
    /**
     * The parsed response body.
     */
    body: any;
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: any;
    };
};
/**
 * Contains response data for the getTokenStatus operation.
 */
export declare type UserTokenGetTokenStatusResponse = Array<TokenStatus> & {
    /**
     * The underlying HTTP response.
     */
    _response: msRest.HttpResponse & {
        /**
         * The response body as text (string format)
         */
        bodyAsText: string;
        /**
         * The response body as parsed JSON or XML
         */
        parsedBody: TokenStatus[];
    };
};
